/* 
Тестировалось на Arduino IDE 1.8.0
Дата тестирования 26.07.2017г.
*/ 

#include <ESP8266WiFi.h>                               // Подключаем библиотеку ESP8266WiFi
#include <OneWire.h>                                   // Подключаем библиотеку Wire
#include <DallasTemperature.h>                         // Подключаем библиотеку DallasTemperature

const char* ssid = "Название Вашей сети";              // Название Вашей WiFi сети
const char* password = "Пароль от Вашей сети";         // Пароль от Вашей WiFi сети

#define ONE_WIRE_BUS 2                                 // Указываем, к какому выводу подключена датчик
OneWire oneWire(ONE_WIRE_BUS);
DallasTemperature DS18B20(&oneWire);
WiFiServer server(80);                                 // Указываем порт Web-сервера

void setup() 
{
  Serial.begin(115200);                                // Скорость передачи 115200 
  delay(10);                                           // Пауза 10 мкс
  DS18B20.begin();                                     // Инициализация DS18B20
                             
  Serial.println("");                                  // Печать пустой строки 
  Serial.print("Connecting to ");                      // Печать "Подключение к:"
  Serial.println(ssid);                                // Печать "Название Вашей WiFi сети"
  
  WiFi.begin(ssid, password);                          // Подключение к WiFi Сети
  
  while (WiFi.status() != WL_CONNECTED)                // Проверка подключения к WiFi сети
  {
   delay(500);                                         // Пауза 500 мкс
   Serial.print(".");                                  // Печать "."
  }
   Serial.println("");                                 // Печать пустой строки                                          
   Serial.println("WiFi connected");                   // Печать "Подключение к WiFi сети осуществлено"
   server.begin();                                     // Запуск Web сервера
   Serial.println("Web server running.");              // Печать "Веб-сервер запущен"
   delay(10000);                                       // Пауза 10 000 мкс
   Serial.println(WiFi.localIP());                     // Печатаем полученный IP-адрес ESP
}

void loop() 
{
 WiFiClient client = server.available();                // Получаем данные, посылаемые клиентом 
  
 if (client){
  Serial.println("New client");                         // Отправка "Новый клиент"
  boolean blank_line = true;                            // Создаем переменную, чтобы определить конец HTTP-запроса 
  while (client.connected()){                           // Пока есть соединение с клиентом 
    if (client.available()){                            // Если клиент активен 
     char c = client.read();                            // Считываем посылаемую информацию в переменную "с"
     if (c == '\n' && blank_line){                      // Вывод HTML страницы 
       DS18B20.requestTemperatures();                   // Запрос на считывание температуры
       client.println("HTTP/1.1 200 OK");               // Стандартный заголовок HTTP 
       client.println("Content-Type: text/html"); 
       client.println("Connection: close");             // Соединение будет закрыто после завершения ответа
       client.println("Refresh: 10");                   // Автоматическое обновление каждые 10 сек 
       client.println();
       client.println("<!DOCTYPE HTML>");               // Веб-страница создается с использованием HTML
       client.println("<html>");                        // Открытие тега HTML 
       client.println("<head>");
       client.print("<title>ESP8266 TEMP</title>");     // Название страницы
       client.println("</head>");
       client.println("<body>");
       client.println("<h1>ESP8266 - Temperature</h1>"); 
       client.println("<h3>Temperature = ");
       client.println(DS18B20.getTempCByIndex(0));      // Отображение температуры
       client.println("*C</h3>");
       client.println("</body>");
       client.println("</html>");                       // Закрытие тега HTML 
       break;                                           // Выход
       }
        if (c == '\n'){                                 // Если "с" равен символу новой строки                                             
         blank_line = true;                             // Тогда начинаем новую строку
        }                                          
         else if (c != '\r'){                           // Если "с" не равен символу возврата курсора на начало строки                                        
          blank_line = false;                           // Тогда получаем символ на текущей строке 
         }                                        
    }
  }  
    client.stop();                                      // Закрытие соединения
    Serial.println("Client disconnected.");             // Печать "Клиент отключен"
}
}   
